<?php
/** 
* ภาษาไทย เวอร์ชั่น 1.3.2 
* 06/01/2555
* ไฟล์ภาษาไทยสำหรับ PHPBB3 โดย www.mindphp.com และ www.phpbbthailand.com
* posting [Thai]
*/ 

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}


$lang = array_merge($lang, array(
	'ADD_ATTACHMENT'			=> 'แนบไฟล์',
	'ADD_ATTACHMENT_EXPLAIN'	=> 'ถ้าคุณต้องการแนบไฟล์ไปกับข้อความนี้ กรุณากรอกรายละเอียดที่ด้านล่าง',
	'ADD_FILE'					=> 'ส่งไฟล์ที่เลือก',
	'ADD_POLL'					=> 'แบบสอบถาม',
	'ADD_POLL_EXPLAIN'			=> 'หากคุณไม่ต้องการเพิ่มแบบสอบถาม กรุณาปล่อยกล่องข้อความหัวข้อให้ค่าว่างไว้',
	'ALREADY_DELETED'			=> 'ขออภัยคุณไม่สามารถลบข้อความนี้ได้',
	'ATTACH_QUOTA_REACHED'		=> 'ไฟล์ที่อัพโหลดขึ้นมา มีขนาดใหญ่เกินไป',
	'ATTACH_SIG'				=> 'แนบลายเซ็นต์ (แก้ไขลายเซ็นต์ได้ที่หน้า แก้ไขข้อมูลส่วนตัว)',

	'BBCODE_A_HELP'				=> 'อัพโหลดไฟล์แนป: [attachment=]filename.ext[/attachment]',
	'BBCODE_B_HELP'				=> 'ข้อความตัวหนา: [b]text[/b]',
	'BBCODE_C_HELP'				=> 'แสดงข้อความเป็นโค้ด: [code]code[/code]',
	'BBCODE_D_HELP'				=> 'Flash: [flash=width,height]http://url[/flash]',
	'BBCODE_F_HELP'				=> 'ขนาดตัวอักษร: [size=x-small]small text[/size]',
	'BBCODE_IS_OFF'				=> '%sBBCode%s <em>ปิด</em>',
	'BBCODE_IS_ON'				=> '%sBBCode%s <em>เปิด</em>',
	'BBCODE_I_HELP'				=> 'ตัวเอียง: [i]text[/i]',
	'BBCODE_L_HELP'				=> 'ลิส: [list]text[/list]',
	'BBCODE_LISTITEM_HELP'		=> 'ลิสรายการ: [*]text[/*]',
	'BBCODE_O_HELP'				=> 'จัดเรียงลิส: [list=]text[/list]',
	'BBCODE_P_HELP'				=> 'ใส่รูป: [img]http://image_url[/img]',
	'BBCODE_Q_HELP'				=> 'เครื่องหมายคำพูดในข้อความ: [quote]text[/quote]',
	'BBCODE_S_HELP'				=> 'สีตัวอักษร: [color=red]text[/color]  สามารถใช้โค้ดสี  #FF0000 ได้',
	'BBCODE_U_HELP'				=> 'ขีดเส้นใต้ข้อความ: [u]text[/u]',
	'BBCODE_W_HELP'				=> 'ใส่ URL: [url]http://url[/url] or [url=http://url]URL text[/url]',
	'BBCODE_Y_HELP'				=> 'ลิส: เพิ่มองค์ประกอบของรายการ',
	'BUMP_ERROR'				=> 'คุณไม่สามารถ bump กระทู้นี้ได้ทันทีหลังจากการโพสต์ครั้งสุดท้าย',

	'CANNOT_DELETE_REPLIED'		=> 'คุณสามารถลบโพสต์ที่ยังไม่ได้มีการตอบกลับเท่านั้น',
	'CANNOT_EDIT_POST_LOCKED'	=> 'ข้อความนี้ถูกล๊อก คุณไม่สามารถแก้ไขหรือลบข้อความนี้ได้',
	'CANNOT_EDIT_TIME'			=> 'คุณไม่สามารถแก้ไขหรือลบข้อความนี้ได้',
	'CANNOT_POST_ANNOUNCE'		=> 'ขออภัยคะ คุณไม่สามารถโพสต์ประกาศได้',
	'CANNOT_POST_STICKY'		=> 'ขออภัยคะ คุณไม่สามารถโพสต์กระทู้ที่ ปักหมุดไว้ได้',
	'CHANGE_TOPIC_TO'			=> 'เปลี่ยนประเภทของกระทู้',
	'CLOSE_TAGS'				=> 'ปิดแท็ก',
	'CURRENT_TOPIC'				=> 'กระทู้ปัจจุบัน',

	'DELETE_FILE'				=> 'ลบไฟล์นี้',
	'DELETE_MESSAGE'			=> 'ลบข้อความ',
	'DELETE_MESSAGE_CONFIRM'	=> 'ต้องการลบข้อความนี้ ?',
	'DELETE_OWN_POSTS'			=> 'ขออภัยคะ คุณสามารถลบข้อความได้แต่ข้อความที่คุณเป็นเจ้าของเท่านั้น',
	'DELETE_POST_CONFIRM'		=> '่ต้องการลบข้อความนี้?',
	'DELETE_POST_WARN'			=> 'หากลบข้อความแล้วไม่สามารถกู้คืนได้',
	'DISABLE_BBCODE'			=> 'ไม่ใช้ BBCode ในข้อความนี้',
	'DISABLE_MAGIC_URL'			=> 'ไม่ต้องแปลง URL ให้เป็นลิงค์',
	'DISABLE_SMILIES'			=> 'ไม่ใช้รูปแสดงอารมณ์ในข้อความนี้',
	'DISALLOWED_CONTENT'		=> 'ข้อมูลในไฟล์ที่อัพโหลดผิดพลาด.',
	'DISALLOWED_EXTENSION'		=> 'ชนิดของไฟล์ %s ไม่อนุญาต.',
	'DRAFT_LOADED'				=> 'โหลดข้อความร่างเข้าพื้นที่โพสต์, คุณอาจจะต้องการให้ข้อความนี้เสร็จสิ้น<br />ข้อความร่างของคุณต้องถูกลบเมื่อคุณได้บันทึกข้อความที่คุณโพสต์แล้ว',
	'DRAFT_LOADED_PM'			=> 'โหลดข้อความร่างเข้าพื้นที่โพสต์, คุณอาจจะต้องการให้ข้อความส่วนตัวนี้เสร็จสิ้น.<br />Yoข้อความร่างของคุณต้องถูกลบเมื่อคุณได้บันทึกข้อความส่วนตัวที่คุณโพสต์แล้ว',
	'DRAFT_SAVED'				=> 'ข้อความร่างถูกบันทึกเรียบร้อย',
	'DRAFT_TITLE'				=> 'หัวข้อข้อความร่าง',

	'EDIT_REASON'				=> 'เหตุผลสำหรับการแก้ไขข้อความนี้',
	'EMPTY_FILEUPLOAD'			=> 'ไม่มีไฟล์ที่อัพโหลด',
	'EMPTY_MESSAGE'				=> 'คุณต้องระบุข้อความเมื่อคุณโฟสต์',
	'EMPTY_REMOTE_DATA'			=> 'ไฟล์ไม่สามารถอัพโหลดได้ , กรุณาอัพโหลด ใหม่อีกครั้ง',

	'FLASH_IS_OFF'				=> '[flash]  <em>ปิด</em>',
	'FLASH_IS_ON'				=> '[flash]  <em>เปิด</em>',
	'FLOOD_ERROR'				=> 'คุณไม่สามารถโพสต์ติดต่อกันภายในเวลาที่เร็วเกินไป.',
	'FONT_COLOR'				=> 'สีตัวอักษร',
	'FONT_COLOR_HIDE'			=> 'ไม่แสดงสีตัวอักษร',
	'FONT_HUGE'					=> 'ใหญ่มาก',
	'FONT_LARGE'				=> 'ใหญ่',
	'FONT_NORMAL'				=> 'ปกติ',
	'FONT_SIZE'					=> 'ขนาดตัวอักษร',
	'FONT_SMALL'				=> 'เล็ก',
	'FONT_TINY'					=> 'เล็กมาก',

	'GENERAL_UPLOAD_ERROR'		=> '่สามารถอัพโหลดไฟล์ %s.',

	'IMAGES_ARE_OFF'			=> '[img] <em>ปิด</em>',
	'IMAGES_ARE_ON'				=> '[img] <em>เปิด</em>',
	'INVALID_FILENAME'			=> '%s ชื่อไฟล์นี้ไม่สามารถใช้งานได้',

	'LOAD'						=> 'โหลด..',
	'LOAD_DRAFT'				=> 'ใช้บันทึกร่าง',
	'LOAD_DRAFT_EXPLAIN'		=> 'คุณสามารถเลือกข้อความร่างที่คุณเขียนค้างไว้เพื่อเขียนต่อ โพสต์ปัจจุบันของคุณจะถูกยกเลิก เนื้อหาการโพสต์ทั้งหมดจะถูกลบ คุณสามารถดู แก้ไข ลบข้อความร่างได้จากแป้นควบคุมของผู้ใช้',
	'LOGIN_EXPLAIN_BUMP'		=> 'คุณต้องเข้าระบบก่อนเพื่อแก้ไขกระทู้ในบอร์ดนี้',
	'LOGIN_EXPLAIN_DELETE'		=> 'คุณต้องเข้าระบบก่อนเพื่อลบกระทู้ในบอร์ดนี้',
	'LOGIN_EXPLAIN_POST'		=> 'คุณต้องเข้าระบบก่อนเพื่อโพสต์ต์ข้อความในบอร์ดนี้',
	'LOGIN_EXPLAIN_QUOTE'		=> 'คุณต้องเข้าระบบก่อนเพื่ออ้างอิงข้อความในบอร์ดนี้',
	'LOGIN_EXPLAIN_REPLY'		=> 'คุณต้องทำการล็อกอินเข้าสู่ระบบสมาชิกก่อนจึงจะสามารถทำการตอบหัวข้อได้.',

	'MAX_FONT_SIZE_EXCEEDED'	=> 'คุณอาจจะใช้ฟอร์นขนาดมากสุดคือ %1$d.',
	'MAX_FLASH_HEIGHT_EXCEEDED'	=> 'ไฟล์ Flash ของคุณมีขนาดความสูงได้มากสุดคือ %1$d พิกเซล',
	'MAX_FLASH_WIDTH_EXCEEDED'	=> 'ไฟล์ Flash ของคุณมีขนาดความกว้างได้มากสุดคือ %1$d พิกเซล',
	'MAX_IMG_HEIGHT_EXCEEDED'	=> 'ไฟล์รูปภาพของคุณมีขนาดความสูงได้มากสุดคือ  %1$d พิกเซล',
	'MAX_IMG_WIDTH_EXCEEDED'	=> 'ไฟล์รูปภาพของคุณมีขนาดความกว้างได้มากสุดคือ  %1$d พิกเซล',

	'MESSAGE_BODY_EXPLAIN'		=> 'กรุณากรอกข้อความของคุณที่นี้,ต้องประกอบด้วยตัวอักษรไม่เกิน <strong>%d</strong> ตัว',
	'MESSAGE_DELETED'			=> 'ข้อความถูกลบเรียบร้อยแล้ว',
	'MORE_SMILIES'				=> 'รูปแสดงอารมณ์อื่นๆ',

	'NOTIFY_REPLY'				=> 'แจ้งเตือนเมื่อมีผู้ตอบ',
	'NOT_UPLOADED'				=> 'ไฟล์ไม่สามารถ Upload ได้',
	'NO_DELETE_POLL_OPTIONS'	=> 'คุณไม่สามารถลบแบบสำรวจได้',
	'NO_PM_ICON'				=> 'ไม่มี ไอคอน PM ',
	'NO_POLL_TITLE'				=> 'คุณต้องกรอกหัวข้อแบบสำรวจ',
	'NO_POST'					=> 'ไม่สามารถโพสต์ข้อความได้',
	'NO_POST_MODE'				=> 'ไม่มีการระบุโพสต์โหมด',

	'PARTIAL_UPLOAD'			=> 'ระบบสามารถ Upload ไฟล์ได้เพียงบางส่วนเท่านั้น',
	'PHP_SIZE_NA'				=> 'ไฟล์แนบมีขนาดใหญ่เกินไป <br />ไม่สามารถระบุขนาดสูงสุดที่กำหนดโดย PHP ในไฟล์ php.ini ได้',
	'PHP_SIZE_OVERRUN'			=> 'ไฟล์แนบมีขนาดใหญ่เกินไป, ขนาดไฟล์ที่ใหญ่ที่สุดคือ %d MB.<br />ค่านี้ถูกกำหนดไว้ที่ php.ini และไม่สามารถเปลี่ยนแปลงได้',
	'PLACE_INLINE'				=> 'แสดงในข้อความ',
	'POLL_DELETE'				=> 'ลบแบบสอบถาม',
	'POLL_FOR'					=> 'เริ่มแบบสอบถามใน',
	'POLL_FOR_EXPLAIN'			=> 'ใส่ 0 หรือปล่อยว่างไว้ เมื่อไม่ต้องการกำหนดระยะเวลา',
	'POLL_MAX_OPTIONS'			=> 'ตัวเลือกสำหรับผู้ใช้ระบบ',
	'POLL_MAX_OPTIONS_EXPLAIN'	=> 'นี่คือจำนวนตัวเลือกที่ผู้ใช้แต่ละคนเลือกได้ในการโหวต',
	'POLL_OPTIONS'				=> 'ตัวเลือกของแบบสำรวจ',
	'POLL_OPTIONS_EXPLAIN'		=> 'วางแต่ละตัวเลือกไว้คนละบรรทัด คุณกรอกได้ไม่เกิน <strong>%d</strong> ตัวเลือก',
	'POLL_OPTIONS_EDIT_EXPLAIN'	=> 'วางตัวเลือกในบรรทัดใหม่. คุณอาจใช้ตัวเลือก <strong>%d</strong>. ถ้าคุณเพิ่มหรือลบตัวเลือก คะแนนโหลวทั้งหมดจะถูกคืนค่าเป็นค่าเริ่มต้น.',
	'POLL_QUESTION'				=> 'คำถามสำหรับแบบสำรวจ',
	'POLL_TITLE_TOO_LONG'		=> 'หัวข้อแบบสำรวจควรมีตัวอักษรอย่างน้อย 100 ตัวอักษร',
	'POLL_TITLE_COMP_TOO_LONG'	=> 'หัวข้อแบบสำรวจมีขนาดใหญ่เกินไป, ควรลบ BBCodes หรือรอยยิ้มออก',
	'POLL_VOTE_CHANGE'			=> 'อนุญาตให้โหวตใหม่ได้',
	'POLL_VOTE_CHANGE_EXPLAIN'	=> 'ถ้าผู้ใช้ระบบสามารถเปลี่ยนแปลงผลการโหวต',
	'POSTED_ATTACHMENTS'		=> 'โพสต์ไฟล์แนบ',
	'POST_APPROVAL_NOTIFY'		=> 'คุณจะได้รับแจ้งเมื่อโพสต์ของคุณได้รับการอนุมัติ.',	
	'POST_CONFIRMATION'			=> 'ยืนยันการโพสต์',
	'POST_CONFIRM_EXPLAIN'		=> 'จำเป็นต้องยืนยันการโพสต์ ถ้าไม่มีรูปขึ้นกรุณาติดต่อ %s ผู้ดูแลเว็บบอร์ด%s.',
	'POST_DELETED'				=> 'ข้อความถูกลบเรียบร้อยแล้ว',
	'POST_EDITED'				=> 'ข้อความถูกแก้ไขเรียบร้อยแล้ว.',
	'POST_EDITED_MOD'			=> 'ข้อความถูกแก้ไขเรียบร้อยแล้ว, แต่ต้องถูกอนุมัติจากผู้ดูแลบอร์ดก่อนถึงจะแสดงในที่สาธารณะได้. คุณจะได้รับการแจ้งเตือนเมื่อข้อความของคุณได้รับการอนุมัติแล้ว',
	'POST_GLOBAL'				=> 'ประกาศเพื่อแสดงทุกหมวด',
	'POST_ICON'					=> 'ไอคอนโพสต์',
	'POST_NORMAL'				=> 'ปกติ',
	'POST_REVIEW'				=> 'แสดงตัวอย่างการโพสต์',
	'POST_REVIEW_EXPLAIN'		=> 'มีข้อความใหม่ในหระทู้นี้. คุณควรที่จะดูตัวอย่างของข้อความที่คุณโพสต์.',

	'POST_REVIEW_EDIT'			=> 'Post review',
	'POST_REVIEW_EDIT_EXPLAIN'	=> 'This post has been altered by another user while you were editing it. You may wish to review the current version of this post and adjust your edits.',
	
	'POST_STORED'				=> 'โพสต์ข้อความเรียบร้อยแล้ว',
	'POST_STORED_MOD'			=> 'บันทึกข้อความเรียบร้อยแล้ว, แต่จะต้องผ่านผู้ดูแลบอร์ดก่อนที่จะแสดงในที่สาธารณะ. คุณจะได้รับการแจ้งเตือน เมื่อข้อความของคุณถูกอนุมัติ.',
	'POST_TOPIC_AS'				=> 'รูปแบบของหัวข้อ',
	'PROGRESS_BAR'				=> 'แถบสถานะการทำงาน',

	'QUOTE_DEPTH_EXCEEDED'		=> 'คุณอาจจะ %1$d อ้างถึงข้อความอื่น',

	'SAVE'						=> 'บันทึกร่าง',
	'SAVE_DATE'					=> 'บันทึกเป็น',
	'SAVE_DRAFT'				=> 'บันทึกข้อความร่าง',
	'SAVE_DRAFT_CONFIRM'		=> 'ข้อความร่างของคุณต้องประกอบด้วยหัวเรื่องและข้อความ,คุณต้องการบันทึกข้อความร่างหรือไม่?',
	'SMILIES'					=> 'รูปแสดงอารมณ์',
	'UI'						=> 'อัพโหลดรูปภาพได้ที่นี่ !!',
	'SMILIES_ARE_OFF'			=> '[Smile icon] <em>ปิด</em>',
	'SMILIES_ARE_ON'			=> '[Smile icon] <em>เปิด</em>',
	'STICKY_ANNOUNCE_TIME_LIMIT'=> 'ปักหมุด/ประกาศจำกัดเวลา',
	'STICK_TOPIC_FOR'			=> 'ระยะเวลาที่ต้องการปักหมุด',

	'STICK_TOPIC_FOR_EXPLAIN'	=> 'ใส่ 0 หรือว่างไว้สำหรับไม่มีการกำหนดวันสินสุดของการปักหมุด/ประกาศ. จำนวนวันที่ใส่จะนับตามวันที่ตั้งกระทู้.',
	
	'STYLES_TIP'				=> 'รูปแบบสามารถใส่ได้ด้วยการเลือกข้อความ.',

	'TOO_FEW_CHARS'				=> 'คุณพิมพ์ข้อความสั้นเกินไป',

	'TOO_FEW_CHARS_LIMIT'		=> 'ข้อความของคุณมี %1$d ตัวอักษร. ต้องกรอกตัวอักษรอย่างน้อย %2$d. ตัว',
	
	'TOO_FEW_POLL_OPTIONS'		=> 'คุณต้องกรอกข้อในแบบสำรวจอย่างน้อย 2 ข้อ',
	'TOO_MANY_ATTACHMENTS'		=> 'ไม่สามารถแนบไฟล์ได้, %d คือค่าสูงสุดแล้ว',
	'TOO_MANY_CHARS'			=> 'ข้อความของคุณยาวเกินไป',
	'TOO_MANY_CHARS_POST'		=> 'ข้อความของคุณ %1$d ตัวอักษร. จำนวนสูงสุดที่อนุญาตให้ใช้อักขระ %2$d. ตัวอักษร',
	'TOO_MANY_CHARS_SIG'		=> 'ลายเซ็นต์ของคุณประกอบด้วย %1$d ตัวอักษร. จำนวนสูงสุดที่อนุญาตให้ใช้อักขระ %2$d. ตัวอักษร',
	'TOO_MANY_POLL_OPTIONS'		=> 'คุณได้พยายามป้อนตัวเลือกของแบบสำรวจเป็นจำนวนมากเกินไป.',
	'TOO_MANY_SMILIES'			=> 'ข้อความของคุณมีรูปรอยยิ้มมากเกินไป.จำนวนสูงสุดของรูปรอยยิ้มที่อนุญาต %d.',
	'TOO_MANY_URLS'				=> 'ข้อความของคุณมี URL มากเกินไป. โพสต์ URL ได้ไม่เกิน %d.',
	'TOO_MANY_USER_OPTIONS'		=> 'คุณไม่สามารถระบุตัวเลือกเพิ่มเติมต่อผู้ใช้ที่มีอยู่กว่าตัวเลือกของแบบสำรวจ',
	'TOPIC_BUMPED'				=> 'กระทู้ของคุณถูกแก้ไขเรียบร้อยแล้ว',

	'UNAUTHORISED_BBCODE'		=> 'คุณไม่สามารถใช้งาน BBCodes: %s.',
	'UNGLOBALISE_EXPLAIN'		=> 'การเปลี่ยนแปลงประเภทของกระทู้จากทั่วไปเป็นธรรมดา, คุณต้องเลือกกระทู้ที่ยังไม่ได้แสดง.',
	'UPDATE_COMMENT'			=> 'แก้ไขคำแนะนำ',
	'URL_INVALID'				=> 'URL นี้ไม่สามารถใช้งานได้',
	'URL_NOT_FOUND'				=> 'ไฟล์ที่คุณระบุไม่มี.',
	'URL_IS_OFF'				=> '[url] <em>ปิด</em>',
	'URL_IS_ON'					=> '[url] <em>เปิด</em>',
	'USER_CANNOT_BUMP'			=> 'คุณไม่สามารถ bump กระทู้ในบอร์ดนี้ได้',
	'USER_CANNOT_DELETE'		=> 'คุณไม่สามารถ ลบ ข้อความในบอร์ดนี้ได้',
	'USER_CANNOT_EDIT'			=> 'คุณไม่สามารถ แก้ไข ข้อความในบอร์ดนี้ได้',
	'USER_CANNOT_REPLY'			=> 'คุณไม่สามารถ ตอบกลับในบอร์ดนี้ได้',
	'USER_CANNOT_FORUM_POST'	=> 'คุณไม่สามารถโพสต์ข้อความได้ เนื่องจากบอร์ดนี้ไม่รองรับ',

	'VIEW_MESSAGE'				=> '%s ดูข้อความที่คุณโพสต์ %s',
	'VIEW_PRIVATE_MESSAGE'		=> '%s แสดงข้อความส่วนตัวที่คุณส่งไป%s',

	'WRONG_FILESIZE'			=> 'ไฟล์มีขนาดใหญ่เกินไป, ขนาดใหญ่สุดคือ %1d %2s.',
	'WRONG_SIZE'				=> 'รูปภาพนี้ควรมีขนาดอย่างน้อยกว้าง  %1$d พิกเซล และสูง %2$d พิกเซล และมากที่สุด กว้าง  %3$d พิกเซล และสูง %4$d พิกเซล รูปภาพของคุณมีขนาดกว้าง %5$d พิกเซล และสูง %6$d พิกเซล ',
));

?>